Token

Enum Token 

pub enum Token {
Show 32 variants Atom(String), Variable(String), Anonymous, Integer(i32), Neck, Query, Comma, Semicolon, Dot, Pipe, Cut, LParen, RParen, LBracket, RBracket, Plus, Minus, Star, Slash, Mod, Is, Unify, NotUnify, Identical, NotIdentical, Lt, Gt, Le, Ge, ArithEq, ArithNe, Eof,
}
Token types for Prolog.

Variants



Atom(String)

Atom: lowercase identifier or quoted string



Variable(String)

Variable: uppercase identifier or underscore



Anonymous

Anonymous variable: _



Integer(i32)

Integer literal



Neck

:- (clause neck / query)



Query

?- (query)



Comma

, (conjunction)



Semicolon

; (disjunction)



Dot

. (end of clause)



Pipe

| (list tail separator)



Cut

! (cut)



LParen

(



RParen

)



LBracket

[



RBracket

]



Plus



Minus



Star



Slash

/



Mod

mod



Is

is



Unify

=



NotUnify

=



Identical

==



NotIdentical

==



Lt

<



Gt



Le

=<



Ge

=



ArithEq

=:=



ArithNe

==



Eof

End of file

Implementations

Source

impl Token

pub fn can_start_term(&self) -> bool

Returns true if this token can start a term.